@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2007 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -7,7 +7,7 @@
  *
  * THIS PACKAGE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
- * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+ * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
 /* WinPlatformFactory:
@@ -29,6 +29,10 @@ class MacPlatformFactory : public PlatformFactory
     BzfVisual* createVisual(const BzfDisplay*);
     BzfWindow* createWindow(const BzfDisplay*, BzfVisual*);
 
+#ifdef HAVE_SDL
+    BzfJoystick* createJoystick();
+#endif
+
   private:
     //MacPlatformFactory(const MacPlatformFactory&);
     //MacPlatformFactory&  operator=(const MacPlatformFactory&);
